Metadata

Struct Metadata 

pub struct Metadata<'a> {
    pub version: &'a str,
    pub cache_key: &'a str,
}
The start of the metadata block Typically at the start of the file

Examples

__metadata:
  version: 8
  cacheKey: 9

will often be represented as:

Metadata {
  version: "8",
  cache_key: "9",
}

Fields

version: &'a str

The version of the lockfile

cache_key: &'a str

The cache key of the lockfile

Implementations

Source

impl<'a> Metadata<'a>

pub const fn new(version: &'a str, cache_key: &'a str) -> Self

Create a new Metadata from a version and a cache key (borrowed)